@@ -27,6 +27,10 @@ VFLOW_PATHS = {'operators':'/files/vflow/subengines/com/sap/python36/',
                'dockerfiles':'/files/vflow/',
                'general':'files/vflow/'}
 
+VFLOW_PATHS2 = {'operators':'files/vflow/subengines/com/sap/python3/operators/',
+                'graphs':'files/vflow/graphs/',
+                'dockerfiles':'files/vflow/dockerfiles/'}
+
 
 def exclude_files(tarinfo) :
     basename = path.basename(tarinfo.name)
@@ -80,6 +84,7 @@ def main() :
                                              'For value "userlist" artifact uploaded to all user in userlist.'
                                              ' Not applicable for solutions-upload')
     parser.add_argument('-g', '--gitcommit', help='Git commit for the uploaded files',action='store_true')
+    parser.add_argument('-x', '--gen2', help='Generation 2 operators',action='store_true')
     args = parser.parse_args()
 
     if args.init :
