@@ -1,3 +1,8 @@
+#
+#  SPDX-FileCopyrightText: 2021 Thorsten Hapke <thorsten.hapke@sap.com>
+#
+#  SPDX-License-Identifier: Apache-2.0
+#
 import logging
 import subprocess
 from os import path
@@ -9,6 +14,12 @@ VFLOW_PATHS = {'bundle':'/',
                'dockerfiles':'/files/vflow/',
                'general':'files/vflow/'}
 
+VFLOW_PATHS2 = {'bundle':'/',
+               'operators':'/files/vflow/subengines/com/sap/python3/',
+               'graphs':'/files/vflow/',
+               'dockerfiles':'/files/vflow/',
+               'general':'files/vflow/'}
+
 def get_dir_files(dir) :
     logging.info(f'List file in folder: {dir}')
     logging.debug(f"vctl vrep user ls {dir}")
@@ -64,7 +75,9 @@ def upload_file(source,target) :
     logging.info(f"Upload file: {source} -> {target}")
     run(['vctl','vrep','user','put',source,target])
 
-def import_artifact(artifact_type,file,user,flags=None) :
+def import_artifact(artifact_type,file,user,flags=None,gen=1) :
+
+    vflows = VFLOW_PATHS2 if gen == 2 else VFLOW_PATHS
     if flags :
         cmd = ['vctl','vrep','user','import',file,VFLOW_PATHS[artifact_type],'-u',user,'-r',flags]
         logging.info(f'Import {artifact_type[:-1]}: {file} to user: {user} ({" ".join(cmd)})')
@@ -74,8 +87,12 @@ def import_artifact(artifact_type,file,user,flags=None) :
         logging.info(f'Import {artifact_type[:-1]}: {file} to user: {user} ({" ".join(cmd)})')
         run(cmd)
 
-def export_artifact(artifact_type,artifact,file,user) :
+def export_artifact(artifact_type,artifact,file,user,gen=1) :
+
     source = path.join(VFLOW_PATHS[artifact_type],artifact)
+    if gen==2:
+        source = path.join(VFLOW_PATHS2[artifact_type],artifact)
+
     cmd = ['vctl','vrep','user','export',file,source,'-u',user]
     logging.info(f'Export \'{source}\' of user \'{user}\' to file: {file} ({" ".join(cmd)})')
     try :
